@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-import concurrent.futures
 import threading
 
 import pytest
@@ -14,7 +13,7 @@ I_TEST = [
     ("壱弍", "一二"),
     ("森鷗外", "森鴎外"),
     ("\U0000845B\U000E0101城市", "\U0000845B城市"),
-    ("\U0000845B\U000E0100飾区", "\U0000845B飾区")
+    ("\U0000845B\U000E0100飾区", "\U0000845B飾区"),
 ]
 
 
@@ -33,19 +32,9 @@ def test_thread_itaiji():
         t.join()
 
 
-@pytest.mark.thread
-@pytest.mark.skip
-def test_threadpool_itaiji():
-    with concurrent.futures.ThreadPoolExecutor(3) as texec:
-        tasks = [texec.submit(worker_itaiji) for _ in range(10)]
-        for task in concurrent.futures.as_completed(tasks):
-            if not task.result():
-                raise Exception("Failed.")
-
-
 def worker_itaiji():
     try:
-        j = pykakasi.kanji.J2("H")
+        j = pykakasi.kanji.JConv()
         for case, result in I_TEST:
             assert j._itaiji.convert(case) == result
     except AssertionError:
@@ -64,21 +53,11 @@ def test_thread_kanwa():
         t.join()
 
 
-@pytest.mark.thread
-@pytest.mark.skip
-def test_threadpool_kanwa():
-    with concurrent.futures.ThreadPoolExecutor(3) as texec:
-        tasks = [texec.submit(worker_kanwa) for _ in range(10)]
-        for task in concurrent.futures.as_completed(tasks):
-            if not task.result():
-                raise Exception("Failed.")
-
-
 def worker_kanwa():
     try:
         k = pykakasi.kanji.Kanwa()
-        d = k.load(u"春")
-        assert d[u"春"] is not None
+        d = k.load("春")
+        assert d["春"] is not None
     except AssertionError:
         return False
     return True
